@@ -15,7 +15,8 @@ import re
 
 GB = 1024. * 1024. * 1024.
 MB = 1024. * 1024.
-_object_id = "OBJECT_ID"
+prefix = "CRED_"
+_object_id = "object_id"
 
 def pytest_addoption(parser):
     """
@@ -77,9 +78,8 @@ def pytest_configure(config):
 @pytest.fixture(scope="session")
 def env(env_file):
     load_dotenv(env_file)
-    prefix = "CRED_"
     my_pattern = re.compile(r'{prefix}\w+'.format(prefix=prefix))
-    my_env_variables = {key.replace(prefix, ''): val.lower() for key, val in os.environ.items() if my_pattern.match(key)}
+    my_env_variables = {key.replace(prefix, '').lower(): val for key, val in os.environ.items() if my_pattern.match(key)}
 
     return my_env_variables
 
@@ -113,8 +113,6 @@ def good_credentials(env):
     keys = list(env.keys())
     values = list(env.values())
     res = {keys[i].lower(): values[i] for i in range(len(keys))}
-    if "USER_NAME" in env.keys():
-        res["username"] = env["USER_NAME"]
     if "CODE" in env.keys():
         res["code"] = None
     return res
@@ -130,12 +128,12 @@ def bad_credentials(env):
 
 @pytest.fixture(scope="session")
 def filtered_column_nm(env):
-    return env["FILTERED_COLUMN_NM"]
+    return env["filtered_column_nm"]
 
 
 @pytest.fixture(scope="session")
 def filtered_column_date_format(env):
-    return env["FILTERED_COLUMN_DATE_FORMAT"]
+    return env["filtered_column_date_format"]
 
 
 @pytest.fixture(scope="session")
@@ -144,13 +142,13 @@ def earliest_date():
 
 
 @pytest.fixture(scope="session")
-def custom_date_start_val():
-    return "1941-03-26"
+def custom_date_start_val(env):
+    return env["start_value_txt"] if "start_value_txt" in env else "1941-03-26"
 
 
 @pytest.fixture(scope="session")
-def custom_date_end_val():
-    return "2000-01-01"
+def custom_date_end_val(env):
+    return env["end_value_txt"] if "end_value_txt" in env else "2000-01-01"
 
 
 @pytest.fixture(scope="session")
@@ -218,17 +216,17 @@ def bad_field_ids(get_all_good_field_ids):
     return field_ids
 
 
-@pytest.fixture(scope="session")
-def bad_filters_data_type(env):
-    # ? maybe have a field called "FILTERED_COLUMN_NM_WRONG_DATA_TYPE"?
-    return {
-        "filtered_column_nm": env["FILTERED_COLUMN_NM"],
-        "start_selection_nm": env["FILTERED_SELECTION_NM"],
-        "end_selection_nm": env["END_SELECTION_NM"],
-        "start_value_txt": env["START_VALUE_TXT"],
-        "end_value_txt": env["END_VALUE_TXT"],
-        "timezone_offset_nbr": int(env["TIMEZONE_OFFSET_NBR"])
-    }
+# @pytest.fixture(scope="session")
+# def bad_filters_data_type(env):
+#     # ? maybe have a field called "FILTERED_COLUMN_NM_WRONG_DATA_TYPE"?
+#     return {
+#         "filtered_column_nm": env["filtered_column_nm"],
+#         "start_selection_nm": env["FILTERED_SELECTION_NM"],
+#         "end_selection_nm": env["END_SELECTION_NM"],
+#         "start_value_txt": env["START_VALUE_TXT"],
+#         "end_value_txt": env["END_VALUE_TXT"],
+#         "timezone_offset_nbr": int(env["TIMEZONE_OFFSET_NBR"])
+#     }
 
 
 @pytest.fixture(scope="session")
