@@ -165,7 +165,7 @@ class TestGetData:
     def test_bad_field_id_throws_error(self, good_object_id, bad_field_ids, connector):
         with pytest.raises(errors.BadFieldIDError):
             connector.authenticate()
-            connector.get_data(good_object_id, bad_field_ids)
+            connector.get_data(good_object_id, bad_field_ids, n_rows=10)
 
     def test_returns_nonempty_dicts_in_list(self, get_good_data_small):
         data = get_good_data_small
